@@ -27,8 +27,8 @@ Usage::
     list_vod_sources_paginator: ListVodSourcesPaginator = client.get_paginator("list_vod_sources")
     ```
 """
-from mypy_boto3_mediatailor.client import MediaTailorClient
-from mypy_boto3_mediatailor.paginator import (
+from .client import MediaTailorClient
+from .paginator import (
     GetChannelSchedulePaginator,
     ListChannelsPaginator,
     ListPlaybackConfigurationsPaginator,
