@@ -31,11 +31,11 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
-    GetChannelScheduleResponseResponseTypeDef,
-    ListChannelsResponseResponseTypeDef,
-    ListPlaybackConfigurationsResponseResponseTypeDef,
-    ListSourceLocationsResponseResponseTypeDef,
-    ListVodSourcesResponseResponseTypeDef,
+    GetChannelScheduleResponseTypeDef,
+    ListChannelsResponseTypeDef,
+    ListPlaybackConfigurationsResponseTypeDef,
+    ListSourceLocationsResponseTypeDef,
+    ListVodSourcesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -50,7 +50,7 @@ __all__ = (
 
 class GetChannelSchedulePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
     """
 
@@ -60,68 +60,68 @@ class GetChannelSchedulePaginator(Boto3Paginator):
         ChannelName: str,
         DurationMinutes: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetChannelScheduleResponseResponseTypeDef]:
+    ) -> Iterator[GetChannelScheduleResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListChannelsResponseResponseTypeDef]:
+    ) -> Iterator[ListChannelsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
 
 class ListPlaybackConfigurationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPlaybackConfigurationsResponseResponseTypeDef]:
+    ) -> Iterator[ListPlaybackConfigurationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
 
 class ListSourceLocationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSourceLocationsResponseResponseTypeDef]:
+    ) -> Iterator[ListSourceLocationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
 
 class ListVodSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
     """
 
     def paginate(
         self, *, SourceLocationName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListVodSourcesResponseResponseTypeDef]:
+    ) -> Iterator[ListVodSourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
