@@ -42,59 +42,59 @@ __all__ = (
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "ChannelTypeDef",
-    "CreateChannelRequestTypeDef",
-    "CreateChannelResponseResponseTypeDef",
-    "CreateProgramRequestTypeDef",
-    "CreateProgramResponseResponseTypeDef",
-    "CreateSourceLocationRequestTypeDef",
-    "CreateSourceLocationResponseResponseTypeDef",
-    "CreateVodSourceRequestTypeDef",
-    "CreateVodSourceResponseResponseTypeDef",
+    "CreateChannelRequestRequestTypeDef",
+    "CreateChannelResponseTypeDef",
+    "CreateProgramRequestRequestTypeDef",
+    "CreateProgramResponseTypeDef",
+    "CreateSourceLocationRequestRequestTypeDef",
+    "CreateSourceLocationResponseTypeDef",
+    "CreateVodSourceRequestRequestTypeDef",
+    "CreateVodSourceResponseTypeDef",
     "DashConfigurationForPutTypeDef",
     "DashConfigurationTypeDef",
     "DashPlaylistSettingsTypeDef",
     "DefaultSegmentDeliveryConfigurationTypeDef",
-    "DeleteChannelPolicyRequestTypeDef",
-    "DeleteChannelRequestTypeDef",
-    "DeletePlaybackConfigurationRequestTypeDef",
-    "DeleteProgramRequestTypeDef",
-    "DeleteSourceLocationRequestTypeDef",
-    "DeleteVodSourceRequestTypeDef",
-    "DescribeChannelRequestTypeDef",
-    "DescribeChannelResponseResponseTypeDef",
-    "DescribeProgramRequestTypeDef",
-    "DescribeProgramResponseResponseTypeDef",
-    "DescribeSourceLocationRequestTypeDef",
-    "DescribeSourceLocationResponseResponseTypeDef",
-    "DescribeVodSourceRequestTypeDef",
-    "DescribeVodSourceResponseResponseTypeDef",
-    "GetChannelPolicyRequestTypeDef",
-    "GetChannelPolicyResponseResponseTypeDef",
-    "GetChannelScheduleRequestTypeDef",
-    "GetChannelScheduleResponseResponseTypeDef",
-    "GetPlaybackConfigurationRequestTypeDef",
-    "GetPlaybackConfigurationResponseResponseTypeDef",
+    "DeleteChannelPolicyRequestRequestTypeDef",
+    "DeleteChannelRequestRequestTypeDef",
+    "DeletePlaybackConfigurationRequestRequestTypeDef",
+    "DeleteProgramRequestRequestTypeDef",
+    "DeleteSourceLocationRequestRequestTypeDef",
+    "DeleteVodSourceRequestRequestTypeDef",
+    "DescribeChannelRequestRequestTypeDef",
+    "DescribeChannelResponseTypeDef",
+    "DescribeProgramRequestRequestTypeDef",
+    "DescribeProgramResponseTypeDef",
+    "DescribeSourceLocationRequestRequestTypeDef",
+    "DescribeSourceLocationResponseTypeDef",
+    "DescribeVodSourceRequestRequestTypeDef",
+    "DescribeVodSourceResponseTypeDef",
+    "GetChannelPolicyRequestRequestTypeDef",
+    "GetChannelPolicyResponseTypeDef",
+    "GetChannelScheduleRequestRequestTypeDef",
+    "GetChannelScheduleResponseTypeDef",
+    "GetPlaybackConfigurationRequestRequestTypeDef",
+    "GetPlaybackConfigurationResponseTypeDef",
     "HlsConfigurationTypeDef",
     "HlsPlaylistSettingsTypeDef",
     "HttpConfigurationTypeDef",
     "HttpPackageConfigurationTypeDef",
-    "ListChannelsRequestTypeDef",
-    "ListChannelsResponseResponseTypeDef",
-    "ListPlaybackConfigurationsRequestTypeDef",
-    "ListPlaybackConfigurationsResponseResponseTypeDef",
-    "ListSourceLocationsRequestTypeDef",
-    "ListSourceLocationsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
-    "ListVodSourcesRequestTypeDef",
-    "ListVodSourcesResponseResponseTypeDef",
+    "ListChannelsRequestRequestTypeDef",
+    "ListChannelsResponseTypeDef",
+    "ListPlaybackConfigurationsRequestRequestTypeDef",
+    "ListPlaybackConfigurationsResponseTypeDef",
+    "ListSourceLocationsRequestRequestTypeDef",
+    "ListSourceLocationsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "ListVodSourcesRequestRequestTypeDef",
+    "ListVodSourcesResponseTypeDef",
     "LivePreRollConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PaginatorConfigTypeDef",
     "PlaybackConfigurationTypeDef",
-    "PutChannelPolicyRequestTypeDef",
-    "PutPlaybackConfigurationRequestTypeDef",
-    "PutPlaybackConfigurationResponseResponseTypeDef",
+    "PutChannelPolicyRequestRequestTypeDef",
+    "PutPlaybackConfigurationRequestRequestTypeDef",
+    "PutPlaybackConfigurationResponseTypeDef",
     "RequestOutputItemTypeDef",
     "ResponseMetadataTypeDef",
     "ResponseOutputItemTypeDef",
@@ -105,17 +105,17 @@ __all__ = (
     "SlateSourceTypeDef",
     "SourceLocationTypeDef",
     "SpliceInsertMessageTypeDef",
-    "StartChannelRequestTypeDef",
-    "StopChannelRequestTypeDef",
-    "TagResourceRequestTypeDef",
+    "StartChannelRequestRequestTypeDef",
+    "StopChannelRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TransitionTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateChannelRequestTypeDef",
-    "UpdateChannelResponseResponseTypeDef",
-    "UpdateSourceLocationRequestTypeDef",
-    "UpdateSourceLocationResponseResponseTypeDef",
-    "UpdateVodSourceRequestTypeDef",
-    "UpdateVodSourceResponseResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateChannelRequestRequestTypeDef",
+    "UpdateChannelResponseTypeDef",
+    "UpdateSourceLocationRequestRequestTypeDef",
+    "UpdateSourceLocationResponseTypeDef",
+    "UpdateVodSourceRequestRequestTypeDef",
+    "UpdateVodSourceResponseTypeDef",
     "VodSourceTypeDef",
 )
 
@@ -199,16 +199,16 @@ class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
     pass
 
 
-_RequiredCreateChannelRequestTypeDef = TypedDict(
-    "_RequiredCreateChannelRequestTypeDef",
+_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": List["RequestOutputItemTypeDef"],
         "PlaybackMode": Literal["LOOP"],
     },
 )
-_OptionalCreateChannelRequestTypeDef = TypedDict(
-    "_OptionalCreateChannelRequestTypeDef",
+_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestRequestTypeDef",
     {
         "Tags": Dict[str, str],
     },
@@ -216,14 +216,14 @@ _OptionalCreateChannelRequestTypeDef = TypedDict(
 )
 
 
-class CreateChannelRequestTypeDef(
-    _RequiredCreateChannelRequestTypeDef, _OptionalCreateChannelRequestTypeDef
+class CreateChannelRequestRequestTypeDef(
+    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
 ):
     pass
 
 
-CreateChannelResponseResponseTypeDef = TypedDict(
-    "CreateChannelResponseResponseTypeDef",
+CreateChannelResponseTypeDef = TypedDict(
+    "CreateChannelResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -237,8 +237,8 @@ CreateChannelResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateProgramRequestTypeDef = TypedDict(
-    "_RequiredCreateProgramRequestTypeDef",
+_RequiredCreateProgramRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProgramRequestRequestTypeDef",
     {
         "ChannelName": str,
         "ProgramName": str,
@@ -247,8 +247,8 @@ _RequiredCreateProgramRequestTypeDef = TypedDict(
         "VodSourceName": str,
     },
 )
-_OptionalCreateProgramRequestTypeDef = TypedDict(
-    "_OptionalCreateProgramRequestTypeDef",
+_OptionalCreateProgramRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProgramRequestRequestTypeDef",
     {
         "AdBreaks": List["AdBreakTypeDef"],
     },
@@ -256,14 +256,14 @@ _OptionalCreateProgramRequestTypeDef = TypedDict(
 )
 
 
-class CreateProgramRequestTypeDef(
-    _RequiredCreateProgramRequestTypeDef, _OptionalCreateProgramRequestTypeDef
+class CreateProgramRequestRequestTypeDef(
+    _RequiredCreateProgramRequestRequestTypeDef, _OptionalCreateProgramRequestRequestTypeDef
 ):
     pass
 
 
-CreateProgramResponseResponseTypeDef = TypedDict(
-    "CreateProgramResponseResponseTypeDef",
+CreateProgramResponseTypeDef = TypedDict(
+    "CreateProgramResponseTypeDef",
     {
         "AdBreaks": List["AdBreakTypeDef"],
         "Arn": str,
@@ -276,15 +276,15 @@ CreateProgramResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateSourceLocationRequestTypeDef = TypedDict(
-    "_RequiredCreateSourceLocationRequestTypeDef",
+_RequiredCreateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
     },
 )
-_OptionalCreateSourceLocationRequestTypeDef = TypedDict(
-    "_OptionalCreateSourceLocationRequestTypeDef",
+_OptionalCreateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSourceLocationRequestRequestTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
@@ -294,14 +294,15 @@ _OptionalCreateSourceLocationRequestTypeDef = TypedDict(
 )
 
 
-class CreateSourceLocationRequestTypeDef(
-    _RequiredCreateSourceLocationRequestTypeDef, _OptionalCreateSourceLocationRequestTypeDef
+class CreateSourceLocationRequestRequestTypeDef(
+    _RequiredCreateSourceLocationRequestRequestTypeDef,
+    _OptionalCreateSourceLocationRequestRequestTypeDef,
 ):
     pass
 
 
-CreateSourceLocationResponseResponseTypeDef = TypedDict(
-    "CreateSourceLocationResponseResponseTypeDef",
+CreateSourceLocationResponseTypeDef = TypedDict(
+    "CreateSourceLocationResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -315,16 +316,16 @@ CreateSourceLocationResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateVodSourceRequestTypeDef = TypedDict(
-    "_RequiredCreateVodSourceRequestTypeDef",
+_RequiredCreateVodSourceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVodSourceRequestRequestTypeDef",
     {
         "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
     },
 )
-_OptionalCreateVodSourceRequestTypeDef = TypedDict(
-    "_OptionalCreateVodSourceRequestTypeDef",
+_OptionalCreateVodSourceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVodSourceRequestRequestTypeDef",
     {
         "Tags": Dict[str, str],
     },
@@ -332,14 +333,14 @@ _OptionalCreateVodSourceRequestTypeDef = TypedDict(
 )
 
 
-class CreateVodSourceRequestTypeDef(
-    _RequiredCreateVodSourceRequestTypeDef, _OptionalCreateVodSourceRequestTypeDef
+class CreateVodSourceRequestRequestTypeDef(
+    _RequiredCreateVodSourceRequestRequestTypeDef, _OptionalCreateVodSourceRequestRequestTypeDef
 ):
     pass
 
 
-CreateVodSourceResponseResponseTypeDef = TypedDict(
-    "CreateVodSourceResponseResponseTypeDef",
+CreateVodSourceResponseTypeDef = TypedDict(
+    "CreateVodSourceResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -390,59 +391,59 @@ DefaultSegmentDeliveryConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-DeleteChannelPolicyRequestTypeDef = TypedDict(
-    "DeleteChannelPolicyRequestTypeDef",
+DeleteChannelPolicyRequestRequestTypeDef = TypedDict(
+    "DeleteChannelPolicyRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-DeleteChannelRequestTypeDef = TypedDict(
-    "DeleteChannelRequestTypeDef",
+DeleteChannelRequestRequestTypeDef = TypedDict(
+    "DeleteChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-DeletePlaybackConfigurationRequestTypeDef = TypedDict(
-    "DeletePlaybackConfigurationRequestTypeDef",
+DeletePlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "DeletePlaybackConfigurationRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DeleteProgramRequestTypeDef = TypedDict(
-    "DeleteProgramRequestTypeDef",
+DeleteProgramRequestRequestTypeDef = TypedDict(
+    "DeleteProgramRequestRequestTypeDef",
     {
         "ChannelName": str,
         "ProgramName": str,
     },
 )
 
-DeleteSourceLocationRequestTypeDef = TypedDict(
-    "DeleteSourceLocationRequestTypeDef",
+DeleteSourceLocationRequestRequestTypeDef = TypedDict(
+    "DeleteSourceLocationRequestRequestTypeDef",
     {
         "SourceLocationName": str,
     },
 )
 
-DeleteVodSourceRequestTypeDef = TypedDict(
-    "DeleteVodSourceRequestTypeDef",
+DeleteVodSourceRequestRequestTypeDef = TypedDict(
+    "DeleteVodSourceRequestRequestTypeDef",
     {
         "SourceLocationName": str,
         "VodSourceName": str,
     },
 )
 
-DescribeChannelRequestTypeDef = TypedDict(
-    "DescribeChannelRequestTypeDef",
+DescribeChannelRequestRequestTypeDef = TypedDict(
+    "DescribeChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-DescribeChannelResponseResponseTypeDef = TypedDict(
-    "DescribeChannelResponseResponseTypeDef",
+DescribeChannelResponseTypeDef = TypedDict(
+    "DescribeChannelResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -456,16 +457,16 @@ DescribeChannelResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeProgramRequestTypeDef = TypedDict(
-    "DescribeProgramRequestTypeDef",
+DescribeProgramRequestRequestTypeDef = TypedDict(
+    "DescribeProgramRequestRequestTypeDef",
     {
         "ChannelName": str,
         "ProgramName": str,
     },
 )
 
-DescribeProgramResponseResponseTypeDef = TypedDict(
-    "DescribeProgramResponseResponseTypeDef",
+DescribeProgramResponseTypeDef = TypedDict(
+    "DescribeProgramResponseTypeDef",
     {
         "AdBreaks": List["AdBreakTypeDef"],
         "Arn": str,
@@ -478,15 +479,15 @@ DescribeProgramResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeSourceLocationRequestTypeDef = TypedDict(
-    "DescribeSourceLocationRequestTypeDef",
+DescribeSourceLocationRequestRequestTypeDef = TypedDict(
+    "DescribeSourceLocationRequestRequestTypeDef",
     {
         "SourceLocationName": str,
     },
 )
 
-DescribeSourceLocationResponseResponseTypeDef = TypedDict(
-    "DescribeSourceLocationResponseResponseTypeDef",
+DescribeSourceLocationResponseTypeDef = TypedDict(
+    "DescribeSourceLocationResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -500,16 +501,16 @@ DescribeSourceLocationResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeVodSourceRequestTypeDef = TypedDict(
-    "DescribeVodSourceRequestTypeDef",
+DescribeVodSourceRequestRequestTypeDef = TypedDict(
+    "DescribeVodSourceRequestRequestTypeDef",
     {
         "SourceLocationName": str,
         "VodSourceName": str,
     },
 )
 
-DescribeVodSourceResponseResponseTypeDef = TypedDict(
-    "DescribeVodSourceResponseResponseTypeDef",
+DescribeVodSourceResponseTypeDef = TypedDict(
+    "DescribeVodSourceResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -522,29 +523,29 @@ DescribeVodSourceResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetChannelPolicyRequestTypeDef = TypedDict(
-    "GetChannelPolicyRequestTypeDef",
+GetChannelPolicyRequestRequestTypeDef = TypedDict(
+    "GetChannelPolicyRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-GetChannelPolicyResponseResponseTypeDef = TypedDict(
-    "GetChannelPolicyResponseResponseTypeDef",
+GetChannelPolicyResponseTypeDef = TypedDict(
+    "GetChannelPolicyResponseTypeDef",
     {
         "Policy": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetChannelScheduleRequestTypeDef = TypedDict(
-    "_RequiredGetChannelScheduleRequestTypeDef",
+_RequiredGetChannelScheduleRequestRequestTypeDef = TypedDict(
+    "_RequiredGetChannelScheduleRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
-_OptionalGetChannelScheduleRequestTypeDef = TypedDict(
-    "_OptionalGetChannelScheduleRequestTypeDef",
+_OptionalGetChannelScheduleRequestRequestTypeDef = TypedDict(
+    "_OptionalGetChannelScheduleRequestRequestTypeDef",
     {
         "DurationMinutes": str,
         "MaxResults": int,
@@ -554,14 +555,15 @@ _OptionalGetChannelScheduleRequestTypeDef = TypedDict(
 )
 
 
-class GetChannelScheduleRequestTypeDef(
-    _RequiredGetChannelScheduleRequestTypeDef, _OptionalGetChannelScheduleRequestTypeDef
+class GetChannelScheduleRequestRequestTypeDef(
+    _RequiredGetChannelScheduleRequestRequestTypeDef,
+    _OptionalGetChannelScheduleRequestRequestTypeDef,
 ):
     pass
 
 
-GetChannelScheduleResponseResponseTypeDef = TypedDict(
-    "GetChannelScheduleResponseResponseTypeDef",
+GetChannelScheduleResponseTypeDef = TypedDict(
+    "GetChannelScheduleResponseTypeDef",
     {
         "Items": List["ScheduleEntryTypeDef"],
         "NextToken": str,
@@ -569,15 +571,15 @@ GetChannelScheduleResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetPlaybackConfigurationRequestTypeDef = TypedDict(
-    "GetPlaybackConfigurationRequestTypeDef",
+GetPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "GetPlaybackConfigurationRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-GetPlaybackConfigurationResponseResponseTypeDef = TypedDict(
-    "GetPlaybackConfigurationResponseResponseTypeDef",
+GetPlaybackConfigurationResponseTypeDef = TypedDict(
+    "GetPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
@@ -633,8 +635,8 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
-ListChannelsRequestTypeDef = TypedDict(
-    "ListChannelsRequestTypeDef",
+ListChannelsRequestRequestTypeDef = TypedDict(
+    "ListChannelsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -642,8 +644,8 @@ ListChannelsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListChannelsResponseResponseTypeDef = TypedDict(
-    "ListChannelsResponseResponseTypeDef",
+ListChannelsResponseTypeDef = TypedDict(
+    "ListChannelsResponseTypeDef",
     {
         "Items": List["ChannelTypeDef"],
         "NextToken": str,
@@ -651,8 +653,8 @@ ListChannelsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPlaybackConfigurationsRequestTypeDef = TypedDict(
-    "ListPlaybackConfigurationsRequestTypeDef",
+ListPlaybackConfigurationsRequestRequestTypeDef = TypedDict(
+    "ListPlaybackConfigurationsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -660,8 +662,8 @@ ListPlaybackConfigurationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPlaybackConfigurationsResponseResponseTypeDef = TypedDict(
-    "ListPlaybackConfigurationsResponseResponseTypeDef",
+ListPlaybackConfigurationsResponseTypeDef = TypedDict(
+    "ListPlaybackConfigurationsResponseTypeDef",
     {
         "Items": List["PlaybackConfigurationTypeDef"],
         "NextToken": str,
@@ -669,8 +671,8 @@ ListPlaybackConfigurationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListSourceLocationsRequestTypeDef = TypedDict(
-    "ListSourceLocationsRequestTypeDef",
+ListSourceLocationsRequestRequestTypeDef = TypedDict(
+    "ListSourceLocationsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -678,8 +680,8 @@ ListSourceLocationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListSourceLocationsResponseResponseTypeDef = TypedDict(
-    "ListSourceLocationsResponseResponseTypeDef",
+ListSourceLocationsResponseTypeDef = TypedDict(
+    "ListSourceLocationsResponseTypeDef",
     {
         "Items": List["SourceLocationTypeDef"],
         "NextToken": str,
@@ -687,29 +689,29 @@ ListSourceLocationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredListVodSourcesRequestTypeDef = TypedDict(
-    "_RequiredListVodSourcesRequestTypeDef",
+_RequiredListVodSourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListVodSourcesRequestRequestTypeDef",
     {
         "SourceLocationName": str,
     },
 )
-_OptionalListVodSourcesRequestTypeDef = TypedDict(
-    "_OptionalListVodSourcesRequestTypeDef",
+_OptionalListVodSourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListVodSourcesRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -718,14 +720,14 @@ _OptionalListVodSourcesRequestTypeDef = TypedDict(
 )
 
 
-class ListVodSourcesRequestTypeDef(
-    _RequiredListVodSourcesRequestTypeDef, _OptionalListVodSourcesRequestTypeDef
+class ListVodSourcesRequestRequestTypeDef(
+    _RequiredListVodSourcesRequestRequestTypeDef, _OptionalListVodSourcesRequestRequestTypeDef
 ):
     pass
 
 
-ListVodSourcesResponseResponseTypeDef = TypedDict(
-    "ListVodSourcesResponseResponseTypeDef",
+ListVodSourcesResponseTypeDef = TypedDict(
+    "ListVodSourcesResponseTypeDef",
     {
         "Items": List["VodSourceTypeDef"],
         "NextToken": str,
@@ -785,16 +787,16 @@ PlaybackConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-PutChannelPolicyRequestTypeDef = TypedDict(
-    "PutChannelPolicyRequestTypeDef",
+PutChannelPolicyRequestRequestTypeDef = TypedDict(
+    "PutChannelPolicyRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Policy": str,
     },
 )
 
-PutPlaybackConfigurationRequestTypeDef = TypedDict(
-    "PutPlaybackConfigurationRequestTypeDef",
+PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "PutPlaybackConfigurationRequestRequestTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
@@ -814,8 +816,8 @@ PutPlaybackConfigurationRequestTypeDef = TypedDict(
     total=False,
 )
 
-PutPlaybackConfigurationResponseResponseTypeDef = TypedDict(
-    "PutPlaybackConfigurationResponseResponseTypeDef",
+PutPlaybackConfigurationResponseTypeDef = TypedDict(
+    "PutPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
@@ -995,22 +997,22 @@ SpliceInsertMessageTypeDef = TypedDict(
     total=False,
 )
 
-StartChannelRequestTypeDef = TypedDict(
-    "StartChannelRequestTypeDef",
+StartChannelRequestRequestTypeDef = TypedDict(
+    "StartChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-StopChannelRequestTypeDef = TypedDict(
-    "StopChannelRequestTypeDef",
+StopChannelRequestRequestTypeDef = TypedDict(
+    "StopChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "Tags": Dict[str, str],
@@ -1037,24 +1039,24 @@ class TransitionTypeDef(_RequiredTransitionTypeDef, _OptionalTransitionTypeDef):
     pass
 
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateChannelRequestTypeDef = TypedDict(
-    "UpdateChannelRequestTypeDef",
+UpdateChannelRequestRequestTypeDef = TypedDict(
+    "UpdateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": List["RequestOutputItemTypeDef"],
     },
 )
 
-UpdateChannelResponseResponseTypeDef = TypedDict(
-    "UpdateChannelResponseResponseTypeDef",
+UpdateChannelResponseTypeDef = TypedDict(
+    "UpdateChannelResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -1068,15 +1070,15 @@ UpdateChannelResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateSourceLocationRequestTypeDef = TypedDict(
-    "_RequiredUpdateSourceLocationRequestTypeDef",
+_RequiredUpdateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
     },
 )
-_OptionalUpdateSourceLocationRequestTypeDef = TypedDict(
-    "_OptionalUpdateSourceLocationRequestTypeDef",
+_OptionalUpdateSourceLocationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSourceLocationRequestRequestTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
@@ -1085,14 +1087,15 @@ _OptionalUpdateSourceLocationRequestTypeDef = TypedDict(
 )
 
 
-class UpdateSourceLocationRequestTypeDef(
-    _RequiredUpdateSourceLocationRequestTypeDef, _OptionalUpdateSourceLocationRequestTypeDef
+class UpdateSourceLocationRequestRequestTypeDef(
+    _RequiredUpdateSourceLocationRequestRequestTypeDef,
+    _OptionalUpdateSourceLocationRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateSourceLocationResponseResponseTypeDef = TypedDict(
-    "UpdateSourceLocationResponseResponseTypeDef",
+UpdateSourceLocationResponseTypeDef = TypedDict(
+    "UpdateSourceLocationResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -1106,8 +1109,8 @@ UpdateSourceLocationResponseResponseTypeDef = TypedDict(
     },
 )
 
-UpdateVodSourceRequestTypeDef = TypedDict(
-    "UpdateVodSourceRequestTypeDef",
+UpdateVodSourceRequestRequestTypeDef = TypedDict(
+    "UpdateVodSourceRequestRequestTypeDef",
     {
         "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
@@ -1115,8 +1118,8 @@ UpdateVodSourceRequestTypeDef = TypedDict(
     },
 )
 
-UpdateVodSourceResponseResponseTypeDef = TypedDict(
-    "UpdateVodSourceResponseResponseTypeDef",
+UpdateVodSourceResponseTypeDef = TypedDict(
+    "UpdateVodSourceResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
